@@ -98,7 +98,7 @@ print CCHARS "#define HAVE_SYS_POLL_H\n" if CheckHeader("sys/poll.h");
 
 print "\n";
 if(1) {
-	@values = sort { $possible{$a} cmp $possible{$b} } keys %possible;
+	@values = sort { $possible{$a} cmp $possible{$b} or $a cmp $b } keys %possible;
 
 	print "Writing termio/termios section of cchars.h... ";
 	print CCHARS "
@@ -170,7 +170,6 @@ XS(XS_Term__ReadKey_GetControlChars)
 #endif
 			croak(\"Unable to read terminal settings in GetControlChars\");
 		else {
-			int i;
 			EXTEND(sp,MAXCC*2);		".join('',map("
 #if defined($values[$_]) && ($values[$_] < LEGALMAXCC)	"."
 PUSHs(sv_2mortal(newSVpv(cc_names[$_],strlen(cc_names[$_])))); /* $possible{$values[$_]} */
@@ -304,7 +303,7 @@ if($SGTTY) {
 	print "Checking symbols\n";
 
 
-	for $c (keys %possible2) {
+	for $c (sort keys %possible2) {
 
 #		if($tchars and !report("
 ##include <sgtty.h>
